import unittest

import sys

sys.path.append("..")

from ork.namegen import NameGenerator


class Test(unittest.TestCase):
    def test_right_cases(self):
        for faction_name in NameGenerator.available_factions.keys():
            for lang in NameGenerator.available_factions[faction_name]:
                print(NameGenerator.generate(faction_name=faction_name, lang=lang))

    def test_unavailable_lang(self):
        self.assertRaises(AssertionError, lambda: NameGenerator.generate(faction_name="orks", lang="it"))



from setuptools import setup

setup(
    name='ork',
    version='0.0.1',
    packages=['ork'],
    package_data={"ork": ["*.json"]},
    url='http://github.com/bonnal-enzo/ork',
    license='Apache 2.0',
    author='Enzo Bonnal',
    author_email='enzobonnal@gmail.com',
    description='Warhammer 40k tool box'
)



from .utils import D66
import json
import os


class NameGenerator:
    """
    Psychic Awakenings -based name generator
    """
    # contains the data from name generators published in psychic awakenings during warhammer 40k v8
    data = json.load(open(os.path.join(os.path.dirname(__file__), "namegen.json"), "r"))

    available_factions = {
        faction_name: list(langs)
        for faction_name, langs in data.items()
    }

    @classmethod
    def generate(cls, faction_name, lang):

        assert faction_name in cls.available_factions.keys(), \
            f"faction '{faction_name}' is not available"

        assert lang in cls.available_factions[faction_name], \
            f"lang '{lang}' is not available for faction '{faction_name}'"

        table = cls.data[faction_name][lang]
        front_bit = table[D66()]["front_bit"]
        uvver_bit = table[D66()]["uvver_bit"]

        if uvver_bit is None:
            return front_bit
        else:
            return f"{front_bit} {uvver_bit}"



from random import randint


def D6():
    """
    Roll a D6
    :return: an integer between 1 and 6 included
    """
    return randint(1, 6)


def D66():
    """
    Roll a D66
    :return: a string that is the concatenation of two D6 rolls
    """
    return str(D6()) + str(D6())
